# Propanol, C3H8O

## Chemical formula

- 1-Propanol: CH3CH2CH2OH
- Isopropanol: (CH3)2CHOH

## Other names

1-Propanol | Isopropanol
--- | ---
Propan-1-ol n-Propyl alcohol n-Propanol n-PrOH Ethylcarbinol 1-Hydroxypropane Propanol Propionic alcohol Propionyl alcohol Propionylol Propyl alcohol Propylic alcohol Propylol | Isopropyl alcohol 2-Propanol Propan-2-ol Isopropyl alcohol Rubbing alcohol Sec-propyl alcohol s-Propanol iPrOH IPA

## External links

- 1-Propanol - Wikipedia
- 1-Propanol - NIST Chemistry WebBook
- Isopropyl alcohol - Wikipedia
- Isopropyl alcohol - NIST Chemistry WebBook